@@ -1,20 +1,14 @@
-# $Id: wetter.py 821 2014-02-01 13:43:48Z mwall $
+# $Id: wetter.py 1156 2014-12-03 19:44:45Z mwall $
 # Copyright 2013 Matthew Wall
+"""
+Upload data to wetter.com
+  http://wetter.com
 
-#==============================================================================
-# wetter.com
-#==============================================================================
-# Upload data to wetter.com
-#  http://wetter.com
-#
-# Installation:
-# 1) put this file in bin/user
-# 2) add the following configuration stanza to weewx.conf
-# 3) restart weewx
-#
-# [Wetter]
-#     username = USERNAME
-#     password = PASSWORD
+[StdRESTful]
+    [[Wetter]]
+        username = USERNAME
+        password = PASSWORD
+"""
 
 import Queue
 import sys
@@ -26,7 +20,13 @@ import urllib2
 import weewx
 import weewx.restx
 import weewx.units
-from weeutil.weeutil import to_bool
+from weeutil.weeutil import to_bool, accumulateLeaves
+
+VERSION = "0.2"
+
+if weewx.__version__ < "3":
+    raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
+                                   weewx.__version__)
 
 def logmsg(level, msg):
     syslog.syslog(level, 'restx: Wetter: %s' % msg)
@@ -41,56 +41,25 @@ def logerr(msg):
     logmsg(syslog.LOG_ERR, msg)
 
 class Wetter(weewx.restx.StdRESTbase):
-    """Upload using the wetter.com protocol."""
-
     def __init__(self, engine, config_dict):
-        """Initialize for posting data to wetter.com.
-
-        Required parameters:
+        """This service recognizes standard restful options plus the following:
 
         username: username
 
         password: password
-
-        Optional parameters:
-
-        server_url: URL of the server
-        Default is the Smart Energy Groups site
-        
-        log_success: If True, log a successful post in the system log.
-        Default is True.
-
-        log_failure: If True, log an unsuccessful post in the system log.
-        Default is True.
-
-        max_backlog: How many records are allowed to accumulate in the queue
-        before the queue is trimmed.
-        Default is sys.maxint (essentially, allow any number).
-
-        max_tries: How many times to try the post before giving up.
-        Default is 3
-
-        stale: How old a record can be and still considered useful.
-        Default is None (never becomes too old).
-
-        post_interval: How long to wait between posts.
-        Default is None (post every record).
-
-        timeout: How long to wait for the server to respond before giving up.
-        Default is 60 seconds
-
-        skip_upload: debugging option to display data but do not upload
-        Default is False
         """
         super(Wetter, self).__init__(engine, config_dict)        
+        loginf("service version is %s" % VERSION)
         try:
-            site_dict = weewx.restx.get_dict(config_dict, 'Wetter')
+            site_dict = config_dict['StdRESTful']['Wetter']
+            site_dict = accumulateLeaves(site_dict, max_level=1)
             site_dict['username']
             site_dict['password']
         except KeyError, e:
             logerr("Data will not be posted: Missing option %s" % e)
             return
-        site_dict.setdefault('database_dict', config_dict['Databases'][config_dict['StdArchive']['archive_database']])
+        site_dict['manager_dict'] = weewx.manager.get_manager_dict(
+            config_dict['DataBindings'], config_dict['Databases'], 'wx_binding')
 
         self.archive_queue = Queue.Queue()
         self.archive_thread = WetterThread(self.archive_queue, **site_dict)
@@ -112,14 +81,14 @@ class WetterThread(weewx.restx.RESTThread):
                  'niederschlagsmenge': ('hourRain',    '%.2f', 10.0), # mm
                  }
 
-    def __init__(self, queue, username, password, database_dict,
+    def __init__(self, queue, username, password, manager_dict,
                  server_url=_SERVER_URL, skip_upload=False,
                  post_interval=None, max_backlog=sys.maxint, stale=None,
                  log_success=True, log_failure=True,
                  timeout=60, max_tries=3, retry_wait=5):
         super(WetterThread, self).__init__(queue,
                                            protocol_name='Wetter',
-                                           database_dict=database_dict,
+                                           manager_dict=manager_dict,
                                            post_interval=post_interval,
                                            max_backlog=max_backlog,
                                            stale=stale,
@@ -133,11 +102,11 @@ class WetterThread(weewx.restx.RESTThread):
         self.server_url = server_url
         self.skip_upload = to_bool(skip_upload)
 
-    def process_record(self, record, archive):
-        r = self.get_record(record, archive)
+    def process_record(self, record, dbm):
+        r = self.get_record(record, dbm)
         data = self.get_data(r)
         if self.skip_upload:
-            logdbg("skipping upload")
+            loginf("skipping upload")
             return
         req = urllib2.Request(self.server_url, urllib.urlencode(data))
         req.get_method = lambda: 'POST'
